@@ -43,6 +43,7 @@ docs = [
     "googlecloudstorage.md",
     "drive.md",
     "googlephotos.md",
+    "hasher.md",
     "hdfs.md",
     "http.md",
     "hubic.md",
@@ -55,6 +56,7 @@ docs = [
     "onedrive.md",
     "opendrive.md",
     "qingstor.md",
+    "sia.md",
     "swift.md",
     "pcloud.md",
     "premiumizeme.md",
