@@ -8,9 +8,15 @@ FUSE.
 
 First set up your remote using |rclone config|.  Check it works with |rclone ls| etc.
 
-On Linux and OSX, you can either run mount in foreground mode or background (daemon) mode.
-Mount runs in foreground mode by default, use the |--daemon| flag to specify background mode.
-You can only run mount in foreground mode on Windows.
+On Linux and macOS, you can run mount in either foreground or background (aka
+daemon) mode. Mount runs in foreground mode by default. Use the |--daemon| flag
+to force background mode. On Windows you can run mount in foreground only,
+the flag is ignored.
+
+In background mode rclone acts as a generic Unix mount program: the main
+program starts, spawns background rclone process to setup and maintain the
+mount, waits until success or timeout and exits with appropriate code
+(killing the child process if it fails).
 
 On Linux/macOS/FreeBSD start the mount like this, where |/path/to/local/mount|
 is an **empty** **existing** directory:
@@ -18,7 +24,11 @@ is an **empty** **existing** directory:
     rclone @ remote:path/to/files /path/to/local/mount
 
 On Windows you can start a mount in different ways. See [below](#mounting-modes-on-windows)
-for details. The following examples will mount to an automatically assigned drive,
+for details. If foreground mount is used interactively from a console window,
+rclone will serve the mount and occupy the console so another window should be
+used to work with the mount until rclone is interrupted e.g. by pressing Ctrl-C.
+
+The following examples will mount to an automatically assigned drive,
 to specific drive letter |X:|, to path |C:\path\parent\mount|
 (where parent directory or drive must exist, and mount must **not** exist,
 and is not supported when [mounting as a network drive](#mounting-modes-on-windows)), and
@@ -50,9 +60,6 @@ then an additional 1 PiB of free space is assumed. If the remote does not
 [support](https://rclone.org/overview/#optional-features) the about feature
 at all, then 1 PiB is set as both the total and the free size.
 
-**Note**: As of |rclone| 1.52.2, |rclone mount| now requires Go version 1.13
-or newer on some platforms depending on the underlying FUSE library in use.
-
 ### Installing on Windows
 
 To run rclone @ on Windows, you will need to
@@ -151,11 +158,16 @@ By default, the owner and group will be taken from the current user, and the bui
 group "Everyone" will be used to represent others. The user/group can be customized
 with FUSE options "UserName" and "GroupName",
 e.g. |-o UserName=user123 -o GroupName="Authenticated Users"|.
+The permissions on each entry will be set according to [options](#options)
+|--dir-perms| and |--file-perms|, which takes a value in traditional
+[numeric notation](https://en.wikipedia.org/wiki/File-system_permissions#Numeric_notation).
 
-The permissions on each entry will be set according to
-[options](#options) |--dir-perms| and |--file-perms|,
-which takes a value in traditional [numeric notation](https://en.wikipedia.org/wiki/File-system_permissions#Numeric_notation),
-where the default corresponds to |--file-perms 0666 --dir-perms 0777|.
+The default permissions corresponds to |--file-perms 0666 --dir-perms 0777|,
+i.e. read and write permissions to everyone. This means you will not be able
+to start any programs from the the mount. To be able to do that you must add
+execute permissions, e.g. |--file-perms 0777 --dir-perms 0777| to add it
+to everyone. If the program needs to write files, chances are you will have
+to enable [VFS File Caching](#vfs-file-caching) as well (see also [limitations](#limitations)).
 
 Note that the mapping of permissions is not always trivial, and the result
 you see in Windows Explorer may not be exactly like you expected.
@@ -228,6 +240,13 @@ Hubic) do not support the concept of empty directories, so empty
 directories will have a tendency to disappear once they fall out of
 the directory cache.
 
+When |rclone mount| is invoked on Unix with |--daemon| flag, the main rclone
+program will wait for the background mount to become ready or until the timeout
+specified by the |--daemon-wait| flag. On Linux it can check mount status using
+ProcFS so the flag in fact sets **maximum** time to wait, while the real wait
+can be less. On macOS / BSD the time to wait is constant and the check is
+performed only at the end. We advise you to set wait time on macOS reasonably.
+
 Only supported on Linux, FreeBSD, OS X and Windows at the moment.
 
 ### rclone @ vs rclone sync/copy
@@ -284,19 +303,82 @@ after the mountpoint has been successfully set up.
 Units having the rclone @ service specified as a requirement
 will see all files and folders immediately in this mode.
 
-### chunked reading
+Note that systemd runs mount units without any environment variables including
+|PATH| or |HOME|. This means that tilde (|~|) expansion will not work
+and you should provide |--config| and |--cache-dir| explicitly as absolute
+paths via rclone arguments.
+Since mounting requires the |fusermount| program, rclone will use the fallback
+PATH of |/bin:/usr/bin| in this scenario. Please ensure that |fusermount|
+is present on this PATH.
 
-|--vfs-read-chunk-size| will enable reading the source objects in parts.
-This can reduce the used download quota for some remotes by requesting only chunks
-from the remote that are actually read at the cost of an increased number of requests.
+### Rclone as Unix mount helper
 
-When |--vfs-read-chunk-size-limit| is also specified and greater than
-|--vfs-read-chunk-size|, the chunk size for each open file will get doubled
-for each chunk read, until the specified value is reached. A value of |-1| will disable
-the limit and the chunk size will grow indefinitely.
+The core Unix program |/bin/mount| normally takes the |-t FSTYPE| argument
+then runs the |/sbin/mount.FSTYPE| helper program passing it mount options
+as |-o key=val,...| or |--opt=...|. Automount (classic or systemd) behaves
+in a similar way.
 
-With |--vfs-read-chunk-size 100M| and |--vfs-read-chunk-size-limit 0|
-the following parts will be downloaded: 0-100M, 100M-200M, 200M-300M, 300M-400M and so on.
-When |--vfs-read-chunk-size-limit 500M| is specified, the result would be
-0-100M, 100M-300M, 300M-700M, 700M-1200M, 1200M-1700M and so on.
+rclone by default expects GNU-style flags |--key val|. To run it as a mount
+helper you should symlink rclone binary to |/sbin/mount.rclone| and optionally
+|/usr/bin/rclonefs|, e.g. |ln -s /usr/bin/rclone /sbin/mount.rclone|.
+rclone will detect it and translate command-line arguments appropriately.
+
+Now you can run classic mounts like this:
+|||
+mount sftp1:subdir /mnt/data -t rclone -o vfs_cache_mode=writes,sftp_key_file=/path/to/pem
+|||
+
+or create systemd mount units:
+|||
+# /etc/systemd/system/mnt-data.mount
+[Unit]
+After=network-online.target
+[Mount]
+Type=rclone
+What=sftp1:subdir
+Where=/mnt/data
+Options=rw,allow_other,args2env,vfs-cache-mode=writes,config=/etc/rclone.conf,cache-dir=/var/rclone
+|||
+
+optionally accompanied by systemd automount unit
+|||
+# /etc/systemd/system/mnt-data.automount
+[Unit]
+After=network-online.target
+Before=remote-fs.target
+[Automount]
+Where=/mnt/data
+TimeoutIdleSec=600
+[Install]
+WantedBy=multi-user.target
+|||
+
+or add in |/etc/fstab| a line like
+|||
+sftp1:subdir /mnt/data rclone rw,noauto,nofail,_netdev,x-systemd.automount,args2env,vfs_cache_mode=writes,config=/etc/rclone.conf,cache_dir=/var/cache/rclone 0 0
+|||
+
+or use classic Automountd.
+Remember to provide explicit |config=...,cache-dir=...| as a workaround for
+mount units being run without |HOME|.
+
+Rclone in the mount helper mode will split |-o| argument(s) by comma, replace |_|
+by |-| and prepend |--| to get the command-line flags. Options containing commas
+or spaces can be wrapped in single or double quotes. Any inner quotes inside outer
+quotes of the same type should be doubled.
+
+Mount option syntax includes a few extra options treated specially:
+
+- |env.NAME=VALUE| will set an environment variable for the mount process.
+  This helps with Automountd and Systemd.mount which don't allow setting
+  custom environment for mount helpers.
+  Typically you will use |env.HTTPS_PROXY=proxy.host:3128| or |env.HOME=/root|
+- |command=cmount| can be used to run |cmount| or any other rclone command
+  rather than the default |mount|.
+- |args2env| will pass mount options to the mount helper running in background
+  via environment variables instead of command line arguments. This allows to
+  hide secrets from such commands as |ps| or |pgrep|.
+- |vv...| will be transformed into appropriate |--verbose=N|
+- standard mount options like |x-systemd.automount|, |_netdev|, |nosuid| and alike
+  are intended only for Automountd and ignored by rclone.
 `
