@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"log"
+	"os"
 
 	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
@@ -80,9 +81,15 @@ func (l *LogLevel) UnmarshalJSON(in []byte) error {
 	})
 }
 
+// LogPrintPid enables process pid in log
+var LogPrintPid = false
+
 // LogPrint sends the text to the logger of level
 var LogPrint = func(level LogLevel, text string) {
 	text = fmt.Sprintf("%-6s: %s", level, text)
+	if LogPrintPid {
+		text = fmt.Sprintf("[%d] %s", os.Getpid(), text)
+	}
 	_ = log.Output(4, text)
 }
 
