@@ -21,18 +21,22 @@ func init() {
 		AuthRequired: true,
 		Fn:           rcList,
 		Title:        "List the given remote and path in JSON format",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:"
-- remote - a path within that remote eg "dir"
+- fs - a remote name string e.g. "drive:"
+- remote - a path within that remote e.g. "dir"
 - opt - a dictionary of options to control the listing (optional)
     - recurse - If set recurse directories
     - noModTime - If set return modification time
     - showEncrypted -  If set show decrypted names
     - showOrigIDs - If set show the IDs for each item if known
     - showHash - If set return a dictionary of hashes
+    - noMimeType - If set don't show mime types
+    - dirsOnly - If set only show directories
+    - filesOnly - If set only show files
+    - hashTypes - array of strings of hash types to show if showHash set
 
-The result is
+Returns:
 
 - list
     - This is an array of objects as described in the lsjson command
@@ -44,7 +48,7 @@ See the [lsjson command](/commands/rclone_lsjson/) for more information on the a
 
 // List the directory
 func rcList(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, remote, err := rc.GetFsAndRemote(in)
+	f, remote, err := rc.GetFsAndRemote(ctx, in)
 	if err != nil {
 		return nil, err
 	}
@@ -66,15 +70,60 @@ func rcList(ctx context.Context, in rc.Params) (out rc.Params, err error) {
 	return out, nil
 }
 
+func init() {
+	rc.Add(rc.Call{
+		Path:         "operations/stat",
+		AuthRequired: true,
+		Fn:           rcStat,
+		Title:        "Give information about the supplied file or directory",
+		Help: `This takes the following parameters
+
+- fs - a remote name string eg "drive:"
+- remote - a path within that remote eg "dir"
+- opt - a dictionary of options to control the listing (optional)
+    - see operations/list for the options
+
+The result is
+
+- item - an object as described in the lsjson command. Will be null if not found.
+
+Note that if you are only interested in files then it is much more
+efficient to set the filesOnly flag in the options.
+
+See the [lsjson command](/commands/rclone_lsjson/) for more information on the above and examples.
+`,
+	})
+}
+
+// List the directory
+func rcStat(ctx context.Context, in rc.Params) (out rc.Params, err error) {
+	f, remote, err := rc.GetFsAndRemote(ctx, in)
+	if err != nil {
+		return nil, err
+	}
+	var opt ListJSONOpt
+	err = in.GetStruct("opt", &opt)
+	if rc.NotErrParamNotFound(err) {
+		return nil, err
+	}
+	item, err := StatJSON(ctx, f, remote, &opt)
+	if err != nil {
+		return nil, err
+	}
+	out = make(rc.Params)
+	out["item"] = item
+	return out, nil
+}
+
 func init() {
 	rc.Add(rc.Call{
 		Path:         "operations/about",
 		AuthRequired: true,
 		Fn:           rcAbout,
 		Title:        "Return the space used on the remote",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:"
+- fs - a remote name string e.g. "drive:"
 
 The result is as returned from rclone about --json
 
@@ -85,7 +134,7 @@ See the [about command](/commands/rclone_size/) command for more information on
 
 // About the remote
 func rcAbout(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, err := rc.GetFs(in)
+	f, err := rc.GetFs(ctx, in)
 	if err != nil {
 		return nil, err
 	}
@@ -118,12 +167,12 @@ func init() {
 				return rcMoveOrCopyFile(ctx, in, copy)
 			},
 			Title: name + " a file from source remote to destination remote",
-			Help: `This takes the following parameters
+			Help: `This takes the following parameters:
 
-- srcFs - a remote name string eg "drive:" for the source
-- srcRemote - a path within that remote eg "file.txt" for the source
-- dstFs - a remote name string eg "drive2:" for the destination
-- dstRemote - a path within that remote eg "file2.txt" for the destination
+- srcFs - a remote name string e.g. "drive:" for the source
+- srcRemote - a path within that remote e.g. "file.txt" for the source
+- dstFs - a remote name string e.g. "drive2:" for the destination
+- dstRemote - a path within that remote e.g. "file2.txt" for the destination
 `,
 		})
 	}
@@ -131,11 +180,11 @@ func init() {
 
 // Copy a file
 func rcMoveOrCopyFile(ctx context.Context, in rc.Params, cp bool) (out rc.Params, err error) {
-	srcFs, srcRemote, err := rc.GetFsAndRemoteNamed(in, "srcFs", "srcRemote")
+	srcFs, srcRemote, err := rc.GetFsAndRemoteNamed(ctx, in, "srcFs", "srcRemote")
 	if err != nil {
 		return nil, err
 	}
-	dstFs, dstRemote, err := rc.GetFsAndRemoteNamed(in, "dstFs", "dstRemote")
+	dstFs, dstRemote, err := rc.GetFsAndRemoteNamed(ctx, in, "dstFs", "dstRemote")
 	if err != nil {
 		return nil, err
 	}
@@ -153,7 +202,7 @@ func init() {
 		{name: "mkdir", title: "Make a destination directory or container"},
 		{name: "rmdir", title: "Remove an empty directory or container"},
 		{name: "purge", title: "Remove a directory or container and all of its contents"},
-		{name: "rmdirs", title: "Remove all the empty directories in the path", help: "- leaveRoot - boolean, set to true not to delete the root\n"},
+		{name: "rmdirs", title: "Remove all the empty directories in the path", help: "- leaveRoot - boolean, set to true not to delete the root"},
 		{name: "delete", title: "Remove files in the path", noRemote: true},
 		{name: "deletefile", title: "Remove the single file pointed to"},
 		{name: "copyurl", title: "Copy the URL to the object", help: "- url - string, URL to read from\n - autoFilename - boolean, set to true to retrieve destination file name from url"},
@@ -161,7 +210,7 @@ func init() {
 		{name: "cleanup", title: "Remove trashed files in the remote or path", noRemote: true},
 	} {
 		op := op
-		remote := "- remote - a path within that remote eg \"dir\"\n"
+		remote := "- remote - a path within that remote e.g. \"dir\"\n"
 		if op.noRemote {
 			remote = ""
 		}
@@ -173,9 +222,9 @@ func init() {
 				return rcSingleCommand(ctx, in, op.name, op.noRemote)
 			},
 			Title: op.title,
-			Help: `This takes the following parameters
+			Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:"
+- fs - a remote name string e.g. "drive:"
 ` + remote + op.help + `
 See the [` + op.name + ` command](/commands/rclone_` + op.name + `/) command for more information on the above.
 `,
@@ -183,16 +232,16 @@ See the [` + op.name + ` command](/commands/rclone_` + op.name + `/) command for
 	}
 }
 
-// Run a single command, eg Mkdir
+// Run a single command, e.g. Mkdir
 func rcSingleCommand(ctx context.Context, in rc.Params, name string, noRemote bool) (out rc.Params, err error) {
 	var (
 		f      fs.Fs
 		remote string
 	)
 	if noRemote {
-		f, err = rc.GetFs(in)
+		f, err = rc.GetFs(ctx, in)
 	} else {
-		f, remote, err = rc.GetFsAndRemote(in)
+		f, remote, err = rc.GetFsAndRemote(ctx, in)
 	}
 	if err != nil {
 		return nil, err
@@ -275,11 +324,11 @@ func init() {
 		AuthRequired: true,
 		Fn:           rcSize,
 		Title:        "Count the number of bytes and files in remote",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:path/to/dir"
+- fs - a remote name string e.g. "drive:path/to/dir"
 
-Returns
+Returns:
 
 - count - number of files
 - bytes - number of bytes in those files
@@ -291,7 +340,7 @@ See the [size command](/commands/rclone_size/) command for more information on t
 
 // Size a directory
 func rcSize(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, err := rc.GetFs(in)
+	f, err := rc.GetFs(ctx, in)
 	if err != nil {
 		return nil, err
 	}
@@ -311,14 +360,14 @@ func init() {
 		AuthRequired: true,
 		Fn:           rcPublicLink,
 		Title:        "Create or retrieve a public link to the given file or folder.",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:"
-- remote - a path within that remote eg "dir"
+- fs - a remote name string e.g. "drive:"
+- remote - a path within that remote e.g. "dir"
 - unlink - boolean - if set removes the link rather than adding it (optional)
-- expire - string - the expiry time of the link eg "1d" (optional)
+- expire - string - the expiry time of the link e.g. "1d" (optional)
 
-Returns
+Returns:
 
 - url - URL of the resource
 
@@ -329,7 +378,7 @@ See the [link command](/commands/rclone_link/) command for more information on t
 
 // Make a public link
 func rcPublicLink(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, remote, err := rc.GetFsAndRemote(in)
+	f, remote, err := rc.GetFsAndRemote(ctx, in)
 	if err != nil {
 		return nil, err
 	}
@@ -352,9 +401,9 @@ func init() {
 		Path:  "operations/fsinfo",
 		Fn:    rcFsInfo,
 		Title: "Return information about the remote",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
-- fs - a remote name string eg "drive:"
+- fs - a remote name string e.g. "drive:"
 
 This returns info about the remote passed in;
 
@@ -413,7 +462,7 @@ This command does not have a command line equivalent so use this instead:
 
 // Fsinfo the remote
 func rcFsInfo(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, err := rc.GetFs(in)
+	f, err := rc.GetFs(ctx, in)
 	if err != nil {
 		return nil, err
 	}
@@ -431,18 +480,18 @@ func init() {
 		AuthRequired: true,
 		Fn:           rcBackend,
 		Title:        "Runs a backend command.",
-		Help: `This takes the following parameters
+		Help: `This takes the following parameters:
 
 - command - a string with the command name
-- fs - a remote name string eg "drive:"
+- fs - a remote name string e.g. "drive:"
 - arg - a list of arguments for the backend command
 - opt - a map of string to string of options
 
-Returns
+Returns:
 
 - result - result from the backend command
 
-For example
+Example:
 
     rclone rc backend/command command=noop fs=. -o echo=yes -o blue -a path1 -a path2
 
@@ -478,7 +527,7 @@ See the [backend](/commands/rclone_backend/) command for more information.
 
 // Make a public link
 func rcBackend(ctx context.Context, in rc.Params) (out rc.Params, err error) {
-	f, err := rc.GetFs(in)
+	f, err := rc.GetFs(ctx, in)
 	if err != nil {
 		return nil, err
 	}
