@@ -32,6 +32,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+const (
+	waitForWritersDelay = 30 * time.Second // time to wait for existing writers
+)
+
 var (
 	mountFn mountlib.MountFn
 )
@@ -227,7 +231,7 @@ func (r *Run) cacheMode(cacheMode vfscommon.CacheMode, writeBack time.Duration)
 		return
 	}
 	// Wait for writers to finish
-	r.vfs.WaitForWriters(30 * time.Second)
+	r.vfs.WaitForWriters(waitForWritersDelay)
 	// Empty and remake the remote
 	r.cleanRemote()
 	err := r.fremote.Mkdir(context.Background(), "")
@@ -372,7 +376,7 @@ func (r *Run) checkDir(t *testing.T, dirString string) {
 
 // wait for any files being written to be released by fuse
 func (r *Run) waitForWriters() {
-	run.vfs.WaitForWriters(10 * time.Second)
+	run.vfs.WaitForWriters(waitForWritersDelay)
 }
 
 // writeFile writes data to a file named by filename.
